Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(490)

Unified Diff: chrome/browser/renderer_host/render_process_host.h

Issue 42054: Stop using renderer specific host ids in ResourceDispatcher. This allows it ... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/renderer_host/render_process_host.h
===================================================================
--- chrome/browser/renderer_host/render_process_host.h (revision 11493)
+++ chrome/browser/renderer_host/render_process_host.h (working copy)
@@ -33,10 +33,10 @@
// Returns the user profile associated with this renderer process.
Profile* profile() const { return profile_; }
// Returns the unique identifier for this host. This can be used later in
// a call to FromID() to get back to this object (this is used to avoid
// sending non-threadsafe pointers to other threads).
- int host_id() const { return host_id_; }
+ int pid() const { return pid_; }
// Returns the process object associated with the child process. In certain
// tests or single-process mode, this will actually represent the current
@@ -172,13 +172,8 @@
static RenderProcessHost* GetExistingProcessHost(Profile* profile);
protected:
- // Unregister this object from all globals that reference it.
- // This would naturally be part of the destructor, but we destruct
- // asynchronously.
- //
- // This can be overridden by derived classes to add their own unregister code,
- // but you should be sure to always call this one AT THE END of your own.
- virtual void Unregister();
+ // Sets the process of this object, so that others access it using FromID.
+ void SetProcessID(int pid);
base::Process process_;
@@ -198,7 +193,7 @@
bool notified_termination_;
private:
- int host_id_;
+ int pid_;
Profile* profile_;
« no previous file with comments | « chrome/browser/renderer_host/browser_render_process_host.cc ('k') | chrome/browser/renderer_host/render_process_host.cc » ('j') | no next file with comments »
@@ -33,10 +33,10 @@
// Returns the user profile associated with this renderer process.
Profile* profile() const { return profile_; }
- // Returns the unique identifier for this host. This can be used later in
+ // Returns the process id for this host. This can be used later in
// a call to FromID() to get back to this object (this is used to avoid
// sending non-threadsafe pointers to other threads).

Powered by Google App Engine
This is Rietveld 408576698